@@ -1,21 +1,17 @@
 from __future__ import unicode_literals
 
 import copy
-import os
 
 from django import forms
+from django.contrib.auth.models import User
 from django.test import TestCase, override_settings
 from django.test.client import RequestFactory
-from django.conf import settings
-from django.contrib.auth.models import User
-from django.contrib.auth.tests.utils import skipIfCustomUser
 from django.utils._os import upath
 
 from formtools.wizard.views import CookieWizardView
 
-from .models import Poet, Poem
 from .forms import temp_storage
-
+from .models import Poem, Poet
 
 # On Python 2, __file__ may end with .pyc
 THIS_FILE = upath(__file__.rstrip("c"))
@@ -233,7 +229,6 @@ class WizardTests(object):
         self.assertEqual(response.status_code, 200)
 
 
-@skipIfCustomUser
 @override_settings(ROOT_URLCONF='tests.wizard.wizardtests.urls')
 class SessionWizardTests(WizardTests, TestCase):
     wizard_url = '/wiz_session/'
@@ -266,7 +261,6 @@ class SessionWizardTests(WizardTests, TestCase):
     )
 
 
-@skipIfCustomUser
 @override_settings(ROOT_URLCONF='tests.wizard.wizardtests.urls')
 class CookieWizardTests(WizardTests, TestCase):
     wizard_url = '/wiz_cookie/'
@@ -299,7 +293,6 @@ class CookieWizardTests(WizardTests, TestCase):
     )
 
 
-@skipIfCustomUser
 @override_settings(ROOT_URLCONF='tests.wizard.wizardtests.urls')
 class WizardTestKwargs(TestCase):
     wizard_url = '/wiz_other_template/'
@@ -336,11 +329,8 @@ class WizardTestKwargs(TestCase):
         self.wizard_step_data[0]['form1-user'] = self.testuser.pk
 
     def test_template(self):
-        templates = os.path.join(os.path.dirname(THIS_FILE), 'templates')
-        with self.settings(
-                TEMPLATE_DIRS=list(settings.TEMPLATE_DIRS) + [templates]):
-            response = self.client.get(self.wizard_url)
-            self.assertTemplateUsed(response, 'other_wizard_form.html')
+        response = self.client.get(self.wizard_url)
+        self.assertTemplateUsed(response, 'other_wizard_form.html')
 
 
 class WizardTestGenericViewInterface(TestCase):
@@ -420,7 +410,6 @@ class WizardTestPrefix(TestCase):
         self.assertEqual(prefix, 'text_prefix')
 
 
-@skipIfCustomUser
 class WizardFormKwargsOverrideTests(TestCase):
     def setUp(self):
         super(WizardFormKwargsOverrideTests, self).setUp()
@@ -462,8 +451,7 @@ class WizardFormKwargsOverrideTests(TestCase):
 
         self.assertNotEqual(formset.queryset, None)
         self.assertEqual(formset.initial_form_count(), 1)
-        self.assertEqual(['staff@example.com'],
-            list(formset.queryset.values_list('email', flat=True)))
+        self.assertEqual(['staff@example.com'], list(formset.queryset.values_list('email', flat=True)))
 
 
 class WizardInlineFormSetTests(TestCase):
